#! /boot/home/config/bin/ruby

#
# bfs.rb
#

require "bfs.so"


class File
  def open_attr(&block)
    Bfs::Attr.open(self, &block)
  end

  def attr_foreach(&block)
    Bfs::Attr.foreach(self, &block)
  end

  def attr_entries
    Bfs::Attr.entries(self)
  end

  def read_attr(*args)
    Bfs::Attr.read(self, *args)
  end

  def write_attr(*args)
    Bfs::Attr.write(self, *args)
  end
  alias addattr write_attr

  def remove_attr(*args)
    Bfs::Attr.rmattr(self, *args)
  end
  alias rmattr remove_attr

  def stat_attr(*args)
    Bfs::Attr.stat(self, *args)
  end
end


module Bfs
  class Volume
    def open_index(&block)
      Bfs::Index.open(self, &block)
    end

    def index_foreach(&block)
      Bfs::Index.foreach(self, &block)
    end

    def index_entries
      Bfs::Index.entries(self)
    end

    def create_index(*args)
      Bfs::Index.mkindex(self, *args)
    end
    alias mkindex create_index

    def remove_index(*args)
      Bfs::Index.rmindex(self, *args)
    end
    alias rmindex remove_index

    def stat_index(*args)
      Bfs::Index.stat(self, *args)
    end

    def open_query(*args, &block)
      Bfs::Query.open(self, *args, &block)
    end

    def query_foreach(*args, &block)
      Bfs::Query.foreach(self, *args, &block)
    end

    def query_entries(*args)
      Bfs::Query.entries(self, *args)
    end
  end
end


if $0 == __FILE__

  File.open("/boot/home") {| f |
    p f                        #=> File obj
    p f.read_attr("BEOS:TYPE") #=> read attribute
    p f.stat_attr("BEOS:TYPE") #=> stat attribute (type & size)
    p f.attr_entries           #=> attribute entries
    f.attr_foreach {|x| p x}
    f.open_attr {|dir| p dir}  #=> open attribute dir
    dir = f.open_attr; p dir; dir.close
    dir = f.open_attr; p dir.grep(/^BE/)
  }

  v = Bfs::Volume.new("/boot")
  p v.index_entries
  puts v.query_entries("name = *ruby*").grep(/bin/).sort

end
